package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.params.AsymmetricKeyParameter;
import cn.com.infosec.crypto.params.ElGamalParameters;
import cn.com.infosec.crypto.params.ElGamalPrivateKeyParameters;
import cn.com.infosec.crypto.params.ElGamalPublicKeyParameters;
import cn.com.infosec.jce.interfaces.ElGamalPrivateKey;
import cn.com.infosec.jce.interfaces.ElGamalPublicKey;
import java.security.InvalidKeyException;
import java.security.PrivateKey;
import java.security.PublicKey;
import javax.crypto.interfaces.DHPrivateKey;
import javax.crypto.interfaces.DHPublicKey;

public class ElGamalUtil {
   public static AsymmetricKeyParameter generatePublicKeyParameter(PublicKey key) {
      if (key instanceof ElGamalPublicKey) {
         ElGamalPublicKey key2 = (ElGamalPublicKey)key;
         return new ElGamalPublicKeyParameters(key2.getY(), new ElGamalParameters(key2.getParameters().getP(), key2.getParameters().getG()));
      } else if (key instanceof DHPublicKey) {
         DHPublicKey key1 = (DHPublicKey)key;
         return new ElGamalPublicKeyParameters(key1.getY(), new ElGamalParameters(key1.getParams().getP(), key1.getParams().getG()));
      } else {
         throw new InvalidKeyException("can't identify public key for El Gamal.");
      }
   }

   public static AsymmetricKeyParameter generatePrivateKeyParameter(PrivateKey key) {
      if (key instanceof ElGamalPrivateKey) {
         ElGamalPrivateKey key2 = (ElGamalPrivateKey)key;
         return new ElGamalPrivateKeyParameters(key2.getX(), new ElGamalParameters(key2.getParameters().getP(), key2.getParameters().getG()));
      } else if (key instanceof DHPrivateKey) {
         DHPrivateKey key1 = (DHPrivateKey)key;
         return new ElGamalPrivateKeyParameters(key1.getX(), new ElGamalParameters(key1.getParams().getP(), key1.getParams().getG()));
      } else {
         throw new InvalidKeyException("can't identify private key for El Gamal.");
      }
   }
}
